#include <iostream>
#include <string>
#include <map>

using namespace std;

int main()
{
	std::map<std::string, double> xsections;

	// Conventions:
	// - upper and lower case can be used for the name. But at the end, the names will be case-insensible.
	// - using units conventions
	// - references must be specified:
	//		-> people can cross-check
	//      -> helpful for writing paperS
	// - do not hesitate to explicite calculation if necessary (ex: BR, k-factor, ...)

  const double ab=1e-3;
  const double fb=1.;
  const double pb=1e3;
  const double nb=1e6;
  const double mb=1e9;

  // -----------------------------------------------
  // ELECTROWEAK
  // -----------------------------------------------

  // ----------- single boson ---------------------------------------------------
  // Reference: FEWZ (10.1016/j.cpc.2011.06.008, 10.1016/j.cpc.2012.09.005)
  // All results are given at the NNLO accuracy
  // ----------------------------------------------------------------------------

  // E1 DrellYan Mll in [10;50]
  xsections["ZToLL10-50.root"]=-1*fb;

  // E2 DrellYan Mll >50
  xsections["ZToLL50.root"]=-1*fb;

  // E3 Z to nunu 
  xsections["ZToNuNu.root"]=-1*fb;

  // E4 W to l nu
  xsections["WToLNu.root"]=-1*fb;

  // ----------- diboson --------------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with MCFM (10.1103/PhysRevD.60.113006, 10.1007/JHEP07(2011)018)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // E5: WW to (l nu) (lnu)
  // All three flavors of leptons are considered
  // rk: 4FNS = no b-quark in the initial state -> removal of the top resonant diagrams
  xsections["WWToLLNuNu.root"]=10.90*pb;

  // E6: WZ to (l nu) (l l)
  // All three flavors of leptons are considered
  xsections["WZToLLLNu.root"]=1.476*pb;

  // E7: WZ to (j j) (l l)
  // All three flavors of leptons are considered
  xsections["WZToLLJJ.root"]=3.056*pb;

  // E8: WZ to (l nu) (nu nu)
  // All three flavors of leptons are considered
  xsections["WZToL3Nu.root"]=2.923*pb;

  // E9: WZ to (j j) (nu nu)
  xsections["WZToNuNujj.root"]=6.051*pb;

  // E10: ZZ to (l l) (l l)
  // All three flavors of leptons are considered
  xsections["ZZTo4L.root"]=144.3*fb;

  // E11: ZZ to (l l) (j j)
  // All three flavors of leptons are considered
  xsections["ZZToLLJJ.root"]=1998.*fb;

  // E12: ZZ to (l l) (nu nu)
  // All three flavors of leptons are considered
  xsections["ZZToLLNuNu.root"]=571.6*fb;

  // E13: ZZ to (j j) (nu nu)
  xsections["ZZToJJNuNu.root"]=3956.*fb;

  // E14: ZZ to (nu nu) (nu nu)
  xsections["ZZTo4Nu.root"]=566.*fb;

  // E15: WW to (l nu) (j j)
  // All three flavors of leptons are considered
  // rk: 4FNS = no b-quark in the initial state -> removal of the top resonant diagrams
  xsections["WWToLNuJJ.root"]=45.15*pb;

  // E16: WZ to (l nu) (j j)
  // All three flavors of leptons are considered
  xsections["WZToLNuJJ.root"]=10.22*pb;

  // ----------- triboson (E17) --------------------------------------------------
  // Reference:
  //
  // ----------------------------------------------------------------------------
  xsections["triboson.root"]=-1*fb;


  // -----------------------------------------------
  // TOP PROCESSES
  // -----------------------------------------------

  // ----------- ttbar ----------------------------------------------------------
  // Reference: Top++ (10.1103/PhysRevLett.110.252004)
  // All results are given at the NNLO+NNLL accuracy
  // ----------------------------------------------------------------------------

  // T1 semileptonic decay mode
  // All three flavors of leptons are considered
  xsections["TTsemilep.root"]=357.0*pb;

  // T2: dileptonic decay mode
  // All three flavors of leptons are considered
  xsections["TTdilep.root"]=86.22*pb;

  // ----------- ttbar+V --------------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with MCFM (10.1007/JHEP07(2012)052)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // T3: ttbar Z to (semileptonic mode) (l l)
  // All three flavors of leptons are considered
  xsections["TTsemilep_ZToLL.root"]=33.70*fb;

  // T4: ttbar Z to (dileptonic mode) (l l)
  // All three flavors of leptons are considered
  xsections["TTdilep_ZToLL.root"]=8.140*fb;

  // T5: ttbar W to (semileptonic mode) (l nu)
  // All three flavors of leptons are considered
  xsections["TTsemilep_WToLNu.root"]=81.00*fb;

  // T7: ttbar W to (dileptonic mode) (l nu)
  // All three flavors of leptons are considered
  xsections["TTdilep_WToLNu.root"]=19.56*fb;

  // ----------- ttbar+V V ------------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // T8: ttbar W W to (semileptonic mode) (l nu) (l nu)
  // All three flavors of leptons are considered
  // rk: 4FNS = no b-quark in the initial state -> removal of the top resonant diagrams
  xsections["TTsemilep_WWToLLNuNu.root"]=461.4*ab;

  // T9: ttbar W W to (dileptonic mode) (l nu) (l nu)
  // All three flavors of leptons are considered
  // rk: 4FNS = no b-quark in the initial state -> removal of the top resonant diagrams
  xsections["TTdilep_WWToLLNuNu.root"]=111.4*ab;

  // T10: ttbar Z Z to (semileptonic mode) (l l) (l l)
  // All three flavors of leptons are considered
  xsections["TTsemilep_ZZTo4L.root"]=8.243*ab;

  // T11: ttbar Z Z to (dileptonic mode) (l l) (l l)
  // All three flavors of leptons are considered
  xsections["TTdilep_ZZTo4L.root"]=1.991*ab;

  // T19: ttbar W Z to (semileptonic mode) (l nu) (l l)
  // All three flavors of leptons are considered
  xsections["TTsemilep_WZTo3LNu.root"]=50.93*ab;

  // T20: ttbar W Z to (dileptonic mode) (l nu) (l l)
  // All three flavors of leptons are considered
  xsections["TTdilep_WZTo3LNu.root"]=12.30*ab;

  // ----------- single top -----------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with MCFM for the t-channel:  10.1103/PhysRevLett.102.182003
  // Cross-checks with MCFM for the s-channel:  10.1103/PhysRevD.70.094012
  // Cross-checks with MCFM for the tW-channel: 10.1016/j.nuclphysb.2005.08.015
  // Cross-checks with MCFM for the tZj-channel: 10.1103/PhysRevD.87.114006
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // T17: s-channel
  // Computation in the 4FNS
  xsections["T_s_channel.root"]=10.01*pb;

  // T16: t-channel
  xsections["T_t_channel.root"]=156.3*pb;

  // T18: tW-channel
  xsections["T_W_channel.root"]=-1*fb;

  // T21 TZq -> trileptonic signature
  xsections["TZqToB3LNuJ.root"]=23.00*fb;

  // -----------------------------------------------
  // -----------------------------------------------
  // HIGGS
  // -----------------------------------------------
  // -----------------------------------------------

  // ----------- single Higgs ---------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with LHC Higgs Xsection working group (arXiv:1307.1347)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // H1-1
  xsections["HToAA.root"]=74.35*fb;

  // H1-2
  xsections["HToBB.root"]=18.82*pb;

  // H1-3 (inclusive in the W decays)
  xsections["HToWW.root"]=7.011*pb;

  // H1-4 (inclusive in the Z decays)
  xsections["HToZZ.root"]=860.9*fb;

  // H1-5
  xsections["HToGG.root"]=2.795*pb;

  // ----------- W + Higgs ------------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with LHC Higgs Xsection working group (arXiv:1307.1347)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // H2-4
  xsections["WHToWAA.root"]=3.235*fb;

  // H2-1
  xsections["WHToWBB.root"]=818.8*fb;

  // H2-2
  xsections["WHToWWW.root"]=305.1*fb;

  // H2-3
  xsections["WHToWZZ.root"]=37.46*fb;

  // ----------- Z + Higgs ------------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with LHC Higgs Xsection working group (arXiv:1307.1347)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // H3-4
  xsections["ZHToZAA.root"]=1.750*fb;

  // H3-1
  xsections["ZHToZBB.root"]=442.8*fb;

  // H3-2
  xsections["ZHToZWW.root"]=165.0*fb;

  // H3-3
  xsections["ZHToZZZ.root"]=20.26*fb;

  // ----------- ttbar + Higgs --------------------------------------------------
  // Reference: aMC@NLO (arXiv:1405.0301)
  // Cross-checks with LHC Higgs Xsection working group (arXiv:1307.1347)
  // All results are given at the NLO accuracy
  // ----------------------------------------------------------------------------

  // H4-1
  xsections["TTHToTTAA.root"]=1.051*fb;

  // H4-2
  xsections["TTHToTTBB.root"]=265.9*fb;

  // H4-3
  xsections["TTHToTTWW.root"]=99.07*fb;

  // H4-4
  xsections["TTHToTTZZ.root"]=12.17*fb;

  // H4-5
  xsections["TTHToTTTauTau.root"]=29.12*fb;

}
